Token class

Constructors

Token({required String token, int? expiration})
const

Properties

expiration → int?
expiration timestamp in milliseconds since epoch
final
hashCode → int
The hash code for this object.
no setterinherited
isExpired → bool
no setter
isValid → bool
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
token → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromJsonString(String? tokenJsonString) → Token?