NextAuthConfig<T> class

Configuration for NextAuth client

Constructors

NextAuthConfig({required String domain, String authBasePath = '/api/auth', required HttpClient httpClient, required SessionSerializer<T> sessionSerializer, Logger? logger, String serverSessionCookieName = "next-auth.session-token", String serverCSRFTokenCookieName = "next-auth.csrf-token"})
Creates a NextAuth configuration

Properties

authBasePath → String
auth api base path (optional)
final
domain → String
server address (required)
final
hashCode → int
The hash code for this object.
no setterinherited
httpClient → HttpClient
HTTP client (required)
final
logger → Logger?
Logger instance (optional)
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
serverCSRFTokenCookieName → String
server CSRF cookie name (optional, must same as the one in the server, default: __Host-next-auth.csrf-token for HTTPS, next-auth.csrf-token for HTTP)
final
serverSessionCookieName → String
server session cookie name (optional, default: __Secure-next-auth.session-token for HTTPS, next-auth.session-token for HTTP, must same as the one in the server)
final
sessionSerializer → SessionSerializer<T>
Session serializer (required)
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited