HttpClient class abstract

Abstract HTTP client interface

Constructors

HttpClient()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

get(String url, {HttpClientOptions? options}) → Future<HttpResponse>
Performs a GET request
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
post(String url, {HttpClientOptions? options, Object? body}) → Future<HttpResponse>
Performs a POST request
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited