HttpClientOptions class

Options for HTTP client requests

Constructors

HttpClientOptions({Map<String, String>? cookies, Map<String, String>? headers, dynamic body, bool? preserveHeaderCase, int? sendTimeout, int? receiveTimeout, String? contentType, dynamic validateStatus(int? status)?, bool? followRedirects, int? maxRedirects, HttpClientResponseType? responseType})
Creates HTTP client options

Properties

body ↔ dynamic
Request body
getter/setter pair
contentType ↔ String?
Content type of the request
getter/setter pair
cookies ↔ Map<String, String>?
Request cookies
getter/setter pair
followRedirects ↔ bool?
Whether to follow redirects
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
headers ↔ Map<String, String>?
Request headers
getter/setter pair
maxRedirects ↔ int?
Maximum number of redirects to follow
getter/setter pair
preserveHeaderCase ↔ bool?
Whether to preserve header case
getter/setter pair
receiveTimeout ↔ int?
Receive timeout in milliseconds
getter/setter pair
responseType ↔ HttpClientResponseType?
Expected response type
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sendTimeout ↔ int?
Send timeout in milliseconds
getter/setter pair
validateStatus ↔ dynamic Function(int? status)?
Function to validate response status
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited