CredentialsSignInOptions class

Options for credentials-based sign in

Constructors

CredentialsSignInOptions({required String email, required String password, String? turnstileToken})
Creates credentials sign in options

Properties

email → String
User email address
final
hashCode → int
The hash code for this object.
no setterinherited
password → String
User password
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
turnstileToken → String?
Optional Turnstile token for bot protection
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, String>
Converts to JSON map
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited