OAuthSignInOptions class

Options for OAuth-based sign in

Constructors

OAuthSignInOptions({required String provider, String? turnstileToken})
Creates OAuth sign in options

Properties

hashCode → int
The hash code for this object.
no setterinherited
provider → String
OAuth provider identifier
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
turnstileToken → String?
Optional Turnstile token for bot protection
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, String>
Converts to JSON map
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited