SignInResponse class

Response from sign in operation

Constructors

SignInResponse({SignInError? error, required int status, required bool ok})
Creates a sign in response

Properties

error → SignInError?
Error information if sign in failed
final
hashCode → int
The hash code for this object.
no setterinherited
ok → bool
Whether the sign in was successful
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status → int
HTTP status code
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited